<?php
/*
*  他のClassの影響を受けていないClass
*/
class MynumberPureClass{

	/*
	*  テーブル作成処理（主にインストール時に実行）
	*/
	/**
	**  OSMP_TABLE = マイナンバーデータ
	**  data_id　データid、 last_name 姓、 first_name 名
	**  mynumber マイナンバー（暗号化データ）
	**  mynumber_img_id 個人番号カードの画像id
	**  certification_img_id 身分証明書の画像id
	**  agreement 利用許諾の同意
	**  delete_flag 削除フラグ
	**  create_time 作成日時、 update_time 更新日時
	**/
	public static function insDataTable(){

		$charset = defined("DB_CHARSET") ? DB_CHARSET : "utf8";
		$sql = "CREATE TABLE " .OSMP_TABLE. " (\n".
				"`data_id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,\n".
				"`last_name` text NOT NULL,\n".
				"`first_name` text NOT NULL,\n".
				"`mynumber` blob NOT NULL,\n".
				"`mynumber_img_id` bigint(20) NOT NULL,\n".
				"`certification_img_id` bigint(20) NOT NULL,\n".
				"`agreement` int(1) NOT NULL DEFAULT '0',\n".
				"`delete_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`create_time` datetime NOT NULL,\n".
				"`update_time` timestamp NOT NULL,\n".
				"PRIMARY KEY (`data_id`)\n".
			") ENGINE = MyISAM DEFAULT CHARSET=".$charset." AUTO_INCREMENT=1 \n";
		// SQL実行
		self::sql_performs($sql);

	}
	/**
	**  OSMP_DETAIL_TABLE = マイナンバーデータの詳細
	**  社員コードや部署などといったデータはこちらに入れる
	**  detail_data_id 詳細データid、 data_id　データid
	**  item_id 項目id、 value_text 内容（テキスト）、 value_int 内容（数字）、 value_time 内容（日時）、value_img 内容（画像）
	**  memo メモ。画像ならMIMEタイプをいれる。
	**  delete_flag 削除フラグ
	**  create_time 作成日時、 update_time 更新日時
	**/
	public static function insDetailDataTable(){

		$charset = defined("DB_CHARSET") ? DB_CHARSET : "utf8";
		$sql = "CREATE TABLE " .OSMP_DETAIL_TABLE. " (\n".
				"`detail_data_id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,\n".
				"`data_id` bigint(20) NOT NULL DEFAULT '0',\n".
				"`item_id` bigint(20) NOT NULL DEFAULT '0',\n".
				"`value_text` text NOT NULL,\n".
				"`value_int` int(20) NOT NULL,\n".
				"`value_time` datetime NOT NULL,\n".
				"`value_img` bigint(20) NOT NULL DEFAULT '0',\n".
				"`memo` text NOT NULL,\n".
				"`delete_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`create_time` datetime NOT NULL,\n".
				"`update_time` timestamp NOT NULL,\n".
				"PRIMARY KEY (`detail_data_id`)\n".
			") ENGINE = MyISAM DEFAULT CHARSET=".$charset." AUTO_INCREMENT=1 \n";
		// SQL実行
		self::sql_performs($sql);

	}
	/**
	**  OSMP_IMAGE_TABLE = マイナンバー、身分証明用画像テーブル
	**  img_id 画像データid
	**  name 画像名、 imgdat 画像のバイナリデータ、 mime MIMEタイプ
	**  delete_flag 削除フラグ
	**  create_time 作成日時、 update_time 更新日時
	**/
	public static function insImageTable(){

		$charset = defined("DB_CHARSET") ? DB_CHARSET : "utf8";
		$sql = "CREATE TABLE " .OSMP_IMAGE_TABLE. " (\n".
				"`img_id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,\n".
				"`name` text NOT NULL,\n".
				"`imgdat` mediumblob NOT NULL,\n".
				"`mime` varchar(64) NOT NULL,\n".
				"`delete_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`create_time` datetime NOT NULL,\n".
				"`update_time` timestamp NOT NULL,\n".
				"PRIMARY KEY (`img_id`)\n".
			") ENGINE = MyISAM DEFAULT CHARSET=".$charset." AUTO_INCREMENT=1 \n";
		// SQL実行
		self::sql_performs($sql);

	}
	/**
	**  OSMP_FORM_ITEM_TABLE = フォーム項目の設定テーブル
	**  社員コードや部署などといった設定項目はこちらに入れる
	**  item_id 項目データid
	**  name 項目名、 key キー、 value_type 0=text 1=int 2=time 3=img
	**  text 説明文、 order 昇順（値が小さいものから順番）
	**  default_flag 絶対項目フラグ 0=削除可（任意項目） 1=削除不可（絶対項目）
	**  delete_flag 削除フラグ
	**  create_time 作成日時、 update_time 更新日時
	**/
	public static function insFormItemTable(){

		$charset = defined("DB_CHARSET") ? DB_CHARSET : "utf8";
		$sql = "CREATE TABLE " .OSMP_FORM_ITEM_TABLE. " (\n".
				"`item_id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,\n".
				"`name` text NOT NULL,\n".
				"`key` varchar(100) NOT NULL,\n".
				"`value_type` int(2) NOT NULL,\n".
				"`text` text NOT NULL,\n".
				"`order` int(5) NOT NULL,\n".
				"`default_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`delete_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`create_time` datetime NOT NULL,\n".
				"`update_time` timestamp NOT NULL,\n".
				"PRIMARY KEY (`item_id`)\n".
			") ENGINE = MyISAM DEFAULT CHARSET=".$charset." AUTO_INCREMENT=1 \n";
		// SQL実行
		self::sql_performs($sql);
		/***
		***  社員コードと部署を作成
		***/
		$now = date_i18n("Y-m-d H:i:s");
		global $wpdb;
		$sql = "INSERT INTO `".OSMP_FORM_ITEM_TABLE."` (`name`,`key`,`value_type`,`text`,`order`,`create_time`,`update_time`) VALUES (%s,%s,%d,%s,%d,%s,%s),(%s,%s,%d,%s,%d,%s,%s)";
		$params = array('社員コード','ecode', 0, '社員コードの入力項目', 0, $now, $now, '部署', 'division', 0, '部署名の入力欄', 1, $now, $now);
		$wpdb->query( $wpdb->prepare($sql, $params) );

	}
	/**
	**  OSMP_MANAGEMENT_TABLE = マイナンバー管理プラグインを管理するテーブル
	**  基本的に当プラグインだけが利用し、ユーザは管理しない。設定データ（オプションデータ）や暗号化した第二パスワードなどをいれる。
	**  management_id　データid
	**  key キー、 data データ、　imgdat 使用するかどうか未定だが、画像データ
	**  delete_flag 削除フラグ
	**  create_time 作成日時、 update_time 更新日時
	**/
	public static function insManagementTable(){

		$charset = defined("DB_CHARSET") ? DB_CHARSET : "utf8";
		$sql = "CREATE TABLE " .OSMP_MANAGEMENT_TABLE. " (\n".
				"`management_id` bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,\n".
				"`key` varchar(100) NOT NULL,\n".
				"`data` text NOT NULL,\n".
				"`imgdat` blob NOT NULL,\n".
				"`delete_flag` int(1) NOT NULL DEFAULT '0',\n".
				"`create_time` datetime NOT NULL,\n".
				"`update_time` timestamp NOT NULL,\n".
				"PRIMARY KEY (`management_id`)\n".
			") ENGINE = MyISAM DEFAULT CHARSET=".$charset." AUTO_INCREMENT=1 \n";
		// SQL実行
		self::sql_performs($sql);
		/***
		***  設定データ（オプションデータ）、提出フォームパスワードデータ、第二パスワードデータを作成。あとで更新するので、パスワードデータは空にする。
		***  設定データは配列をシリアライズして保存する。
		***/
		$now = date_i18n("Y-m-d H:i:s");
		$option_data = array('licensekey'=>'', 'formpassword_flag'=>0, 'formpassword_num'=>0, 'ippermit'=>'', 'ipblock'=>'', 'password_flag'=>0, 'password_num'=>0);
		global $wpdb;
		$sql = "INSERT INTO `".OSMP_MANAGEMENT_TABLE."` (`key`,`data`,`create_time`,`update_time`) VALUES (%s,%s,%s,%s),(%s,%s,%s,%s),(%s,%s,%s,%s)";
		$params = array('option', serialize($option_data), $now, $now, 'formpassword', '', $now, $now, 'password', '', $now, $now);
		$wpdb->query( $wpdb->prepare($sql, $params) );

	}
	/*
	*  テーブル作成時に使用
	*/
	// テーブルの存在チェック
	public static function show_table($tbl){

		global $wpdb;
		return $wpdb->get_var($wpdb->prepare("SHOW TABLES LIKE %s", $tbl));

	}
	// sqlを操作するファイルを読み込み、sqlを実行
	public static function sql_performs($sql=''){

		// 関数が使用できなければファイル読み込み
		if(!function_exists('dbDelta')){
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		}

		return dbDelta($sql);

	}
	/*
	*  メール
	*/
	// メールで通知
	public static function notification_wp_mail($str=''){

		$now = date_i18n("Y-m-d H:i:s");
		//
		switch($str){
			case 'install':
				$text = 'インストールしました'."\r\n\r\n";
				break;
			default:
				$text = '';
		}
		//
		global $osmp_option_data;
		// ライセンス
		if(isset($osmp_option_data) && isset($osmp_option_data['licensekey'])){
			$license = $osmp_option_data['licensekey'];
		}else{
			$license = "-";
		}
		$em = 'wpplugin@olivesystem.com';
		$admin_email = get_option('admin_email');
		$subject = 'OSMP通知メール';
		$headers = 'From: OSMP自動メール <'.$admin_email.'>'."\r\n";
		$message = $text
			."通知日時：".$now."\r\n\r\n"
			."=== インストール状況 ==="."\r\n\r\n"
			."サイト名：".get_option('blogname')."\r\n"
			."URL：".get_option('home')."\r\n"
			."WPバージョン：".get_bloginfo('version')."\r\n"
			."プラグイン名：マイナンバー管理プラグイン"."\r\n"
			."プラグインバージョン:".OSMP_VERSION."\r\n"
			."ライセンスキー：".$license."\r\n"
			."\r\n"
		;
		wp_mail($em, $subject, $message, $headers);

	}
	/*
	*  提出フォーム用の固定ページを追加
	*  ショートコードを含ませる
	*/
	public static function make_form_page(){

		// 提出フォーム用ページが存在するかチェックする
		$args = array(
			'name'=>'mynumber-form', 'post_type'=>'page', 'post_status'=>'publish', 'posts_per_page'=>1,
		);
		$get_my_posts = get_posts( $args );
		// データがなければ実行
		if(!$get_my_posts){
			// 投稿オブジェクトを作成
			$my_post = array(
				'post_title'=>'マイナンバー提出フォーム', 'post_name'=>'mynumber-form', 'post_type'=>'page', 'post_content'=>'[mynumber-form]', 'post_status'=>'publish', 'post_author'=> 1,
			);
			// 固定ページをデータベースへ追加
			wp_insert_post( $my_post );
		}

	}
}
/*
*  下記はプラグインのインストール時に使用する関数など ==============
*/
// 定期実行登録用
function osmp_notification_wp_mail($str=''){
	MynumberPureClass::notification_wp_mail($str);
}
// プラグインが有効化されたときに実行する
function osmp_activation_plugin(){
	// テーブルが存在しなければ作成
	if(!MynumberPureClass::show_table(OSMP_TABLE)){
		MynumberPureClass::insDataTable();
	}
	if(!MynumberPureClass::show_table(OSMP_DETAIL_TABLE)){
		MynumberPureClass::insDetailDataTable();
	}
	if(!MynumberPureClass::show_table(OSMP_IMAGE_TABLE)){
		MynumberPureClass::insImageTable();
	}
	if(!MynumberPureClass::show_table(OSMP_FORM_ITEM_TABLE)){
		MynumberPureClass::insFormItemTable();
	}
	if(!MynumberPureClass::show_table(OSMP_MANAGEMENT_TABLE)){
		MynumberPureClass::insManagementTable();
	}
	//
	MynumberPureClass::make_form_page();
	osmp_notification_wp_mail('install');
}
// プラグイン有効化がなされたら
if(function_exists('register_activation_hook')){
	register_activation_hook(OSMP_FILE, 'osmp_activation_plugin');
}
// cron登録処理
if ( !wp_next_scheduled( 'osmp_notification_wp_mail' ) ) {
	wp_schedule_event(time(), 'daily', 'osmp_notification_wp_mail');
}