<?php
/*
*  SQL Class
*/
class MynumberSql extends MynumberCommonClass {

	/*
	*  マイナンバーのフォームデータ（項目データ）
	*/
	// マイナンバーのフォーム項目を新規作成
	// 成功ならitem_idを返し、失敗ならFALSEを返す
	public static function insert_formitem($post){

		global $wpdb;
		$name = (isset($post['name'])) ? $post['name']: '';
		$key = (isset($post['key'])) ? $post['key']: '';
		$value_type = (isset($post['value_type'])) ? $post['value_type']: '';
		$order = (isset($post['order'])) ? $post['order']: '';
		$now = date_i18n("Y-m-d H:i:s");
		$sql = "INSERT INTO `".OSMP_FORM_ITEM_TABLE."` (`name`, `key`, `value_type`, `order`, `create_time`, `update_time`) VALUES (%s, %s, %d, %d, %s, %s)";
		$wpdb->query( $wpdb->prepare($sql, array($name, $key, $value_type, $order, $now, $now)) );
		// 成功なら
		if($id = $wpdb->insert_id){
			return $id;
		}else{
			self::error_behavior($wpdb);
			return FALSE;
		}

	}
	// マイナンバーのフォーム項目をアップデート
	// 成功ならTRUE
	public static function update_formitem($post){

		global $wpdb;
		$now = date_i18n("Y-m-d H:i:s");
		$result = TRUE; // 更新対象がない場合があるので初期はTRUEにする
		//
		foreach($post as $i => $p){
			$updflag = (isset($p['updflag'])) ? $p['updflag']: 0;
			// 更新フラグがあれば
			if(!empty($updflag)){
				$item_id = (isset($p['item_id'])) ? $p['item_id']: 0;
				$name = (isset($p['name'])) ? $p['name']: '';
				$key = (isset($p['key'])) ? $p['key']: '';
				$value_type = (isset($p['value_type'])) ? $p['value_type']: '';
				$order = (isset($p['order'])) ? $p['order']: '';
				$sql = "UPDATE `".OSMP_FORM_ITEM_TABLE."` SET `name`=%s, `key`=%s, `value_type`=%d, `order`=%d, `update_time`=%s WHERE `item_id`=%d AND `delete_flag`=%d";
				$result = $wpdb->query( $wpdb->prepare($sql, array($name, $key, $value_type, $order, $now, $item_id, 0)) );
				// 失敗なら
				if($result===FALSE){
					self::error_behavior($wpdb);
					break;
				}
			}
		}

		return $result;

	}
	// マイナンバーのフォーム項目を取得
	public static function get_formitem_data(){

		global $wpdb;
		$sql = "SELECT * FROM `".OSMP_FORM_ITEM_TABLE."` WHERE `delete_flag`=%d ORDER by `order` ASC";
		return $wpdb->get_results( $wpdb->prepare($sql, array(0)), ARRAY_A);

	}
	// マイナンバーのフォーム項目を削除
	// 成功ならTRUE
	public static function delete_formitem($item_id){

		global $wpdb;
		$now = date_i18n("Y-m-d H:i:s");
		$sql = "UPDATE `".OSMP_FORM_ITEM_TABLE."` SET `delete_flag`=%d, `update_time`=%s WHERE `item_id`=%d";
		$result = $wpdb->query( $wpdb->prepare($sql, array(1, $now, $item_id)) );
		// 失敗なら
		if($result===FALSE){
			self::error_behavior($wpdb);
			return FALSE;
		}else{
			return TRUE;
		}

	}
	/*
	*  マイナンバーデータ
	*/
	// マイナンバー取得
	// マイナンバーそのものは割り当てられたidをもとにして暗号化されているため、一旦データを取得してから取得しなおす
	// マイナンバーそのものの検索は考慮しないものとする
	public static function get_mynumber_data($array=array()){

		$data = array();
		$total = 0;
		$page = 1;
		global $wpdb;
		$params = array();
		$where = '';
		$order = '';
		$asc =
		$limit = '';
		$ct = (!empty($array['ct']) && is_numeric($array['ct'])) ? $array['ct']: 20;
		// データid
		if(!empty($array['id'])){
			$where .= "`data_id`=%d AND ";
			$params[] = $array['id'];
		}
		// 姓
		if(!empty($array['last_name'])){
			$where .= "`last_name`=%s AND ";
			$params[] = $array['last_name'];
		}
		// 名
		if(!empty($array['first_name'])){
			$where .= "`first_name`=%s AND ";
			$params[] = $array['first_name'];
		}
		// マイナンバー下3桁
		if(!empty($array['mynumber3']) && is_numeric($array['mynumber3']) && strlen($array['mynumber3'])==3){
			$where .= MynumberCipherClass::aes_decrypt('mynumber')." LIKE %s AND ";
			$params[] = '%'.self::esc_like($array['mynumber3']);
		}
		// 提出日
		if(!empty($array['create_time'])){
			$where .= "`create_time` LIKE %s AND ";
			$params[] = '%'.self::esc_like($array['create_time']).'%';
		}
		// where文を整理
		$search_detail = self::search_detail_data($array, $params);
		$params = $search_detail['params'];
		$where = $search_detail['where'].$where."`delete_flag`=%d";
		$params[] = 0;
		// 総数取得
		$sql = "SELECT COUNT(`data_id`) as `ct` FROM `".OSMP_TABLE."` WHERE ".$where;
		$get_data = $wpdb->get_results( $wpdb->prepare($sql, $params), ARRAY_A);
		//総数があれば
		if(isset($get_data[0]) && isset($get_data[0]['ct'])){
			$total = $get_data[0]['ct'];
			// 続けてデータの処理をしていく
			// ページ数
			if(!empty($array['pnum']) && is_numeric($array['pnum'])){
				$page = (1<$array['pnum']) ? $array['pnum']: 1;
			}
			// 順番にするアイテム
			if(!empty($array['order'])){
				switch($array['order']){
					default:
						$order = " ORDER by `data_id`";
				}
			}else{
				$order = " ORDER by `data_id`";
			}
			// 昇順か降順か
			if(!empty($array['asc'])){
				$order .= " ASC";
			}else{
				$order .= " DESC";
			}
			//
			$end = $page * $ct;
			$start = $end - $ct;
			//
			if(isset($array['all']) && $array['all']==1){
				// 全件取得なのでlimitなし
			}else{
				if(!empty($array['id'])){ // データid指定なので1件だけ
					$limit = " LIMIT 1";
				}else{ // 指定件数を取得
					$limit = " LIMIT ".$start.",".$ct;
				}
			}
			// データ取得
			$sql = "SELECT *,".MynumberCipherClass::aes_decrypt('mynumber')." as `mynumber_data` FROM `".OSMP_TABLE."` WHERE ".$where.$order.$limit;
			$get_data = $wpdb->get_results( $wpdb->prepare($sql, $params), ARRAY_A);
			// 置き換え及び詳細データを取得
			if(!empty($get_data)){
				$cipher = new MynumberCipherClass();
				//
				foreach($get_data as $i => $d){
					$data[$i] = $d;
					// 復号化しているものと置き換え
					$data[$i]['mynumber'] = $d['mynumber_data'];
					unset($data[$i]['mynumber_data']); // 削除
					// 詳細を取得
					$detail_sql = "SELECT * FROM `".OSMP_DETAIL_TABLE."` as `detail`, `".OSMP_FORM_ITEM_TABLE."` as `item` WHERE `detail`.`data_id`=%d AND `detail`.`item_id`=`item`.`item_id`";
					$detail_result = $wpdb->get_results( $wpdb->prepare($detail_sql, array($d['data_id'])), ARRAY_A);
					// 整理
					if(!empty($detail_result)){
						foreach($detail_result as $detail){
							$item_key = $detail['key'];
							$data[$i]['detail'][$item_key] = $detail;
						}
					}
				}
			}
		}

		return array('data'=>$data, 'total'=>$total, 'page'=>$page);

	}
	// 詳細データ取得し、上記データ用に整理
	public static function search_detail_data($array, $params=array()){

		global $wpdb;
		$data_id_where = '';
		$detail_sql = '';
		$detail_params = array();
		// item_というキーは詳細データの検索に利用していると仮定
		// AND検索とする
		if(!empty($array)){
			foreach($array as $key => $val){
				if(preg_match('/^item_([a-zA-Z0-9_-]+)$/u', trim($key), $m)){
					$detail_sql = "`".esc_sql($m[1])."`=".self::is_num($val)." AND ";
					$detail_params[] = trim($val);
				}
			}
		}
		// 詳細取得
		if(!empty($detail_sql)){
			$detail_sql = "SELECT `data_id` FROM `".OSMP_DETAIL_TABLE."` WHERE ".rtrim($detail_sql, " AND ");
			$get_detail = $wpdb->get_results( $wpdb->prepare($detail_sql, $detail_params), ARRAY_A);
			$cache = array();
			// データがあれば
			if(!empty($get_detail)){
				foreach($get_detail as $g){
					$data_id = $g['data_id'];
					// 既存データがなければ
					if(array_search($data_id, $cache)===FALSE){
						$cache[] = $data_id;
						$data_id_where = "`data_id`=%s OR ";
						$params[] = $data_id;
					}
				}
				//
				$data_id_where = '('.rtrim($data_id_where, " OR ").') AND ';
			}
		}

		return array('where'=>$data_id_where, 'params'=>$params);

	}
	// 同一のマイナンバーがないかチェック
	public static function mynumber_data_check($mynumber=''){

		global $wpdb;
		$sql = "SELECT ".MynumberCipherClass::aes_decrypt('mynumber')." as `mynumber_data` FROM `".OSMP_TABLE."` WHERE ".MynumberCipherClass::aes_decrypt('mynumber')."=%s";
		$result = $wpdb->get_results( $wpdb->prepare($sql, array($mynumber)), ARRAY_A);
		//
		if(!empty($result)){
			return TRUE;
		}else{
			return FALSE;
		}

	}
	// 最も若いデータを取得
	public static function mynumber_young_data($type='create'){

		global $wpdb;
		//
		switch($type){
			case 'id':
				$order = " ORDER by `data_id` DESC";
				break;
			default:
				$order = " ORDER by `create_time` DESC";
		}
		$sql = "SELECT * FROM `".OSMP_TABLE."` WHERE `delete_flag`=%d".$order." LIMIT 1";
		return $wpdb->get_results( $wpdb->prepare($sql, array(0)), ARRAY_A);

	}
	/*
	*  マイナンバーデータの新規作成もしくは更新
	*/
	public static function update_mynumber_data($array=array(), $type='insert'){

		global $wpdb;
		$now = date_i18n("Y-m-d H:i:s");
		$last_name = (isset($array['last_name'])) ? $array['last_name']: '';
		$first_name = (isset($array['first_name'])) ? $array['first_name']: '';
		$agreement = (!empty($array['agreement'])) ? 1: 0;
		// マイナンバー画像があれば
		$mynumber_img_array = self::post_imagedata('mynumber_img');
		extract($mynumber_img_array, EXTR_PREFIX_ALL, 'mynumber');
		// 身分証明画像があれば
		$certification_img_array = self::post_imagedata('certification_img');
		extract($certification_img_array, EXTR_PREFIX_ALL, 'certification');
		// ファイルサイズが12MBより大きければfalse
		if(12000000<$mynumber_imgfilesize || 12000000<$certification_imgfilesize){
			return FALSE;
		}
		//　マイナンバーは、新規作成でも更新でも、一度実行してから更新する
		switch($type){
			// 更新 =================================
			case 'update':
				$data_id = (isset($array['data_id'])) ? $array['data_id']: 0;
				$set = "`last_name`=%s, `first_name`=%s, ";
				$params = array($last_name, $first_name, $data_id);
				// マイナンバー画像の更新用idがあれば
				if(!empty($array['mynumber_img_checkbox']) && !empty($mynumber_imgdat)){
					$mime = (isset($mynumber_imagesize['mime'])) ? $mynumber_imagesize['mime']: '';
					// idがあれば更新
					if(!empty($array['mynumber_img_id'])){
						// 成功なら
						if($upd_id = self::image_data_insert($mynumber_imgname, $mynumber_imgdat, $mime, '', $now, $array['mynumber_img_id'])){
						}else{
							return FALSE;
						}
					}else{ // なければ新規作成
						// 成功なら
						if($insert_id = self::image_data_insert($mynumber_imgname, $mynumber_imgdat, $mime, $now, $now)){
							$set .= "`mynumber_img_id`=%d, ";
							$params = array_merge($params, array($insert_id));
						}else{ // 失敗
							return FALSE;
						}
					}
				}
				// 身分証明画像の更新用idがあれば
				if(!empty($array['certification_img_checkbox']) && !empty($certification_imgdat)){
					$mime = (isset($certification_imagesize['mime'])) ? $certification_imagesize['mime']: '';
					// idがあれば更新
					if(!empty($array['certification_img_id'])){
						// 成功なら
						if($upd_id = self::image_data_insert($certification_imgname, $certification_imgdat, $mime, '', $now, $array['certification_img_id'])){
						}else{
							return FALSE;
						}
					}else{ // なければ新規作成
						// 成功なら
						if($insert_id = self::image_data_insert($certification_imgname, $certification_imgdat, $mime, $now, $now)){
							$set .= "`certification_img_id`=%d, ";
							$params = array_merge($params, array($insert_id));
						}else{ // 失敗
							return FALSE;
						}
					}
				}
				// 姓名データを更新
				$sql = "UPDATE `".OSMP_TABLE."` SET ".rtrim($set, ", ")." WHERE `data_id`=%d";
				$result = $wpdb->query( $wpdb->prepare($sql, $params) );
				// 失敗なら
				if($result===FALSE) return FALSE;
				break;
			// 新規作成 =================================
			default:
				$mynumber_img_id = 0;
				$certification_img_id = 0;
				$create_time = (!empty($array['create_time'])) ? $array['create_time']: $now;
				// マイナンバー画像バイナリデータがあれば
				if(isset($mynumber_imgdat)){
					$mime = (isset($mynumber_imagesize['mime'])) ? $mynumber_imagesize['mime']: '';
					// 成功なら
					if($insert_id = self::image_data_insert($mynumber_imgname, $mynumber_imgdat, $mime, $create_time, $now)){
						$mynumber_img_id = $insert_id;
					}else{ // 失敗
						return FALSE;
					}
				}
				// 身分証明画像バイナリデータがあれば
				if(isset($certification_imgdat)){
					$mime = (isset($certification_imagesize['mime'])) ? $certification_imagesize['mime']: '';
					// 成功なら
					if($insert_id = self::image_data_insert($certification_imgname, $certification_imgdat, $mime, $create_time, $now)){
						$certification_img_id = $insert_id;
					}else{ // 失敗
						return FALSE;
					}
				}
				// 姓名データ、画像idを挿入
				$sql = "INSERT INTO `".OSMP_TABLE."` (`last_name`,`first_name`,`mynumber_img_id`,`certification_img_id`,`agreement`,`create_time`) VALUES (%s,%s,%d,%d,%d,%s)";
				$params = array($last_name, $first_name, $mynumber_img_id, $certification_img_id, $agreement, $now);
				$wpdb->query( $wpdb->prepare($sql, $params) );
				// 成功なら
				if($insert_id = $wpdb->insert_id){
					$data_id = $insert_id;
				}else{ // 失敗
					return FALSE;
				}
		}
		// マイナンバーデータを反映
		$cipher = new MynumberCipherClass();
		$mynumber = (isset($array['mynumber'])) ? $array['mynumber']: '';
		$sql = "UPDATE `".OSMP_TABLE."` SET `mynumber`=".$cipher->aes_encrypt('%s').", `update_time`=%s WHERE `data_id`=%d";
		$result = $wpdb->query( $wpdb->prepare($sql, array($mynumber, $now, $data_id)) );
		// 失敗なら
		if($result===FALSE) return FALSE;
		// 他の項目の処理
		$detail_id = self::update_mynumber_detail_data($array, $data_id, $type);
		// 失敗なら
		if($detail_id===FALSE) return FALSE;

		return $data_id;

	}
	// 詳細データの新規作成及び更新
	public static function update_mynumber_detail_data($array=array(), $data_id='', $type='insert'){

		global $wpdb;
		$wpdb->show_errors();
		$now = date_i18n("Y-m-d H:i:s");
		//
		if(!empty($array['item'])){
			$item = $array['item'];
			foreach($item as $key => $val){
				$params = array();
				$item_id = (isset($val['item_id'])) ? $val['item_id']: 0;
				$detail_id = (isset($val['detail_id'])) ? $val['detail_id']: 0;
				$value = (isset($val['value'])) ? $val['value']: 0;
				$value_type = (isset($val['value_type'])) ? $val['value_type']: 0;
				//
				switch($type){
					// 更新 =================================
					case 'update':
						//
						switch($value_type){
							case 3:
								$img_array = self::post_imagedata('item_img', $item_id);
								$str = 'item_img_checkbox'.$item_id;
								// データがあれば
								if(!empty($array[$str]) && !empty($img_array)){
									extract($img_array, EXTR_PREFIX_ALL, 'item');
									// ファイルサイズが12MBより大きければfalse
									if(12000000<$item_imgfilesize){
										return FALSE;
									}
									$mime = (isset($item_imagesize['mime'])) ? $item_imagesize['mime']: '';
									// 更新SQL
									if(!empty($detail_id)){
										$img_id = (isset($val['value_img'])) ? $val['value_img']: 0;
										// 成功なら
										if($upd_id = self::image_data_insert($item_imgname, $item_imgdat, $mime, '', $now, $img_id)){
										}else{
											return FALSE;
										}
										$set = "`value_img`=%d, ";
									}else{ // 新規作成SQL
										// 成功なら
										if($insert_id = self::image_data_insert($item_imgname, $item_imgdat, $mime, $now, $now)){
											$img_id = $insert_id;
										}else{ // 失敗
											return FALSE;
										}
										$set = "`value_img`,";
										$set_value = "%d,";
									}
									$params = array($img_id);
								}
								break;
							case 2:
								// 更新SQL
								if(!empty($detail_id)){
									$set = "`value_time`=%s, ";
								}else{ // 新規SQL
									$set = "`value_time`,";
									$set_value = "%s,";
								}
								$params = array($value);
								break;
							case 1:
								// 更新SQL
								if(!empty($detail_id)){
									$set = "`value_int`=%d, ";
								}else{ // 新規SQL
									$set = "`value_int`,";
									$set_value = "%d,";
								}
								$params = array($value);
								break;
							default:
								// 更新SQL
								if(!empty($detail_id)){
									$set = "`value_text`=%s, ";
								}else{ // 新規SQL
									$set = "`value_text`,";
									$set_value = "%s,";
								}
								$params = array($value);
						}
						// 更新
						if(!empty($set) && isset($params)){
							// 詳細idがあれば更新
							if(!empty($detail_id)){
								$sql = "UPDATE `".OSMP_DETAIL_TABLE."` SET {$set}`update_time`=%s WHERE `item_id`=%d AND `detail_data_id`=%d";
								$params = array_merge($params, array($now, $item_id, $detail_id));
								$result = $wpdb->query( $wpdb->prepare($sql, $params) );
								// 失敗なら
								if($result===FALSE){
									return FALSE;
								}
							}else{ // item_idがない時は新規作成
								$sql = "INSERT INTO `".OSMP_DETAIL_TABLE."` (".$set."`data_id`,`item_id`,`create_time`) VALUES (".$set_value."%d,%d,%s)";
								$params = array_merge($params, array($data_id, $item_id, $now));
								$wpdb->query( $wpdb->prepare($sql, $params) );
								// 成功なら
								if($insert_id = $wpdb->insert_id){
									$detail_id = $insert_id;
								}else{ // 失敗
									return FALSE;
								}
								// アンセット
								unset($set_value);
							}
							// アンセット
							unset($set); unset($params);
						}
						break;
					// 新規作成 =================================
					default:
						//
						switch($value_type){
							case 3:
								$img_array = self::post_imagedata('item_img', $item_id);
								// データがあれば
								if(!empty($img_array)){
									extract($img_array, EXTR_PREFIX_ALL, 'item');
									// ファイルサイズが12MBより大きければfalse
									if(12000000<$item_imgfilesize){
										return FALSE;
									}
									$mime = (isset($item_imagesize['mime'])) ? $item_imagesize['mime']: '';
									// 成功なら
									if($insert_id = self::image_data_insert($item_imgname, $item_imgdat, $mime, $now, $now)){
										$img_id = $insert_id;
									}else{ // 失敗
										return FALSE;
									}
									$set = "`value_img`,";
									$set_value = "%d,";
									$params = array($img_id);
								}
								break;
							case 2:
								$set = "`value_time`,";
								$set_value = "%s,";
								$params = array($value);
								break;
							case 1:
								$set = "`value_int`,";
								$set_value = "%d,";
								$params = array($value);
								break;
							default:
								$set = "`value_text`,";
								$set_value = "%s,";
								$params = array($value);
						}
						//
						if(!empty($set) && isset($params)){
							$sql = "INSERT INTO `".OSMP_DETAIL_TABLE."` (".$set."`data_id`,`item_id`,`create_time`) VALUES (".$set_value."%d,%d,%s)";
							$params = array_merge($params, array($data_id, $item_id, $now));
							$wpdb->query( $wpdb->prepare($sql, $params) );
							// 成功なら
							if($insert_id = $wpdb->insert_id){
								$detail_id = $insert_id;
							}else{ // 失敗
								return FALSE;
							}
							// アンセット
							unset($set); unset($params);
						}
				}
			}
		}

		return $detail_id;

	}
	// 画像のインサート、アップデート
	public static function image_data_insert($imgname, $imgdat, $mime, $create_time='', $now, $img_id=''){

		global $wpdb;
		// 画像idがあれば更新
		if(!empty($img_id)){
			$sql = "UPDATE `".OSMP_IMAGE_TABLE."` SET `name`=%s, `imgdat`=%s, `mime`=%s, `update_time`=%s WHERE `img_id`=%d";
			$result = $wpdb->query( $wpdb->prepare($sql, array($imgname, $imgdat, $mime, $now, $img_id)) );
			// 失敗なら
			if($result===FALSE){
				return FALSE;
			}
		}else{ // 新規作成
			$sql = "INSERT INTO `".OSMP_IMAGE_TABLE."` (`name`, `imgdat`, `mime`, `create_time`, `update_time`) VALUES (%s,%s,%s,%s,%s)";
			$wpdb->query( $wpdb->prepare($sql, array($imgname, $imgdat, $mime, $create_time, $now)) );
			// 成功なら
			if($insert_id = $wpdb->insert_id){
				$img_id = $insert_id;
			}else{ // 失敗
				return FALSE;
			}
		}

		return $img_id;

	}
	// マイナンバーデータを削除（フラグ）
	public static function delete_mynumber_data($data_id='0'){

		global $wpdb;
		$sql = "UPDATE `".OSMP_TABLE."` SET `delete_flag`=%d WHERE `data_id`=%d";
		$result = $wpdb->query( $wpdb->prepare($sql, array(1, $data_id)) );
		// 失敗なら
		if($result===FALSE){
			return FALSE;
		}else{ // 成功なら
			$sql = "UPDATE `".OSMP_DETAIL_TABLE."` SET `delete_flag`=%d WHERE `data_id`=%d";
			$result = $wpdb->query( $wpdb->prepare($sql, array(1, $data_id)) );
			return TRUE;
		}

	}
	// 投稿した画像データ取得
	public static function post_imagedata($key='', $i=''){

		include_once(OSMP_PLUGIN_DIR."class/imageClass.php");
		return MynumberImageClass::post_imagedata($key, $i);

	}
	// 数値か文字か
	public static function is_num($str=''){

		if(is_numeric($str)){
			return '%d';
		}else{
			return '%s';
		}

	}
	// likeエスケープ
	public static function esc_like($str=''){

		global $wp_version;
		$version = intval(substr($wp_version, 0, 1));
		// バージョン4からlike_escapeは非推奨。$wpdb->esc_like()を使用する
		if($version>=4){
			global $wpdb;
			return $wpdb->esc_like($str);
		}else{
			return like_escape($str);
		}

	}
	/*
	*  オプション
	*/
	//// 更新
	public static function update_option($post){

		if(!empty($post)){
			$formpassword = (!empty($post['formpassword_flag']) && isset($post['formpassword'])) ? $post['formpassword']: '';
			$post['formpassword_num'] = strlen($formpassword);
			$password = (!empty($post['password_flag']) && isset($post['password'])) ? $post['password']: '';
			$post['password_num'] = strlen($password);
			// 不要なものをアンセット
			unset($post['submit']); unset($post['formpassword']); unset($post['password']); unset($post['re_password']); unset($post['_wpnonce']);
			// シリアライズ
			$option_data = serialize($post);
			// プラグイン設定をアップデート
			global $wpdb;
			$sql = "UPDATE `".OSMP_MANAGEMENT_TABLE."` SET `data`=%s WHERE `key`=%s AND `delete_flag`=%d";
			$result = $wpdb->query( $wpdb->prepare($sql, array($option_data, 'option', 0)) );
			// 成功
			if($result!==FALSE){
				// 提出フォームパスワードのアップデート
				if(!empty($formpassword)){
					$sql = "UPDATE `".OSMP_MANAGEMENT_TABLE."` SET `data`=%s WHERE `key`=%s AND `delete_flag`=%d";
					$formpassword_result = $wpdb->query( $wpdb->prepare($sql, array(wp_hash_password($formpassword), 'formpassword', 0)) );
					// 失敗
					if($formpassword_result===FALSE){
						self::error_behavior($wpdb);
						return false;
					}
				}
				// 第二パスワードのアップデート
				if(!empty($password)){
					$sql = "UPDATE `".OSMP_MANAGEMENT_TABLE."` SET `data`=%s WHERE `key`=%s AND `delete_flag`=%d";
					$password_result = $wpdb->query( $wpdb->prepare($sql, array(wp_hash_password($password), 'password', 0)) );
					// 失敗
					if($password_result===FALSE){
						self::error_behavior($wpdb);
						return false;
					}
				}
			}else{
				self::error_behavior($wpdb);
				return false;
			}
			return true;
		}else{
			return false;
		}

	}
	/*
	*  エラー時の処理
	*/
	public static function error_behavior($wpdb){

		if(!empty($wpdb->last_error)){
			echo print_r($wpdb->last_error, true);
			exit;
		}

	}

}